#[repr(transparent)]pub struct IntCtrl(pub u32);Expand description
Interrupt Control Register
Tuple Fields
0: u32Implementations
Sourceimpl IntCtrl
impl IntCtrl
Sourcepub const fn hw_err(&self) -> IntCtrlHwErr
pub const fn hw_err(&self) -> IntCtrlHwErr
Bit position that can be cleared if corresponding bit of INT_STATUS register has been asserted.
Sourcepub const fn set_hw_err(&mut self, val: IntCtrlHwErr)
pub const fn set_hw_err(&mut self, val: IntCtrlHwErr)
Bit position that can be cleared if corresponding bit of INT_STATUS register has been asserted.
Sourcepub const fn ent_val(&self) -> IntCtrlEntVal
pub const fn ent_val(&self) -> IntCtrlEntVal
Same behavior as bit 0 of this register.
Sourcepub const fn set_ent_val(&mut self, val: IntCtrlEntVal)
pub const fn set_ent_val(&mut self, val: IntCtrlEntVal)
Same behavior as bit 0 of this register.
Sourcepub const fn frq_ct_fail(&self) -> IntCtrlFrqCtFail
pub const fn frq_ct_fail(&self) -> IntCtrlFrqCtFail
Same behavior as bit 0 of this register.
Sourcepub const fn set_frq_ct_fail(&mut self, val: IntCtrlFrqCtFail)
pub const fn set_frq_ct_fail(&mut self, val: IntCtrlFrqCtFail)
Same behavior as bit 0 of this register.