nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

IntMask

Struct IntMask 

#[repr(transparent)]
pub struct IntMask(pub u32);
Mask Register

Tuple Fields

0: u32

Implementations

Source

impl IntMask

pub const fn hw_err(&self) -> IntMaskHwErr

Bit position that can be cleared or set to enable the corresponding bit of INT_STATUS to show interupt status

pub const fn set_hw_err(&mut self, val: IntMaskHwErr)

Bit position that can be cleared or set to enable the corresponding bit of INT_STATUS to show interupt status

pub const fn ent_val(&self) -> IntMaskEntVal

Same behavior as bit 0 of this register.

pub const fn set_ent_val(&mut self, val: IntMaskEntVal)

Same behavior as bit 0 of this register.

pub const fn frq_ct_fail(&self) -> IntMaskFrqCtFail

Same behavior as bit 0 of this register.

pub const fn set_frq_ct_fail(&mut self, val: IntMaskFrqCtFail)

Same behavior as bit 0 of this register.