#[repr(transparent)]pub struct Mctl(pub u32);Expand description
Miscellaneous Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Mctl
impl Mctl
Sourcepub const fn set_samp_mode(&mut self, val: SampMode)
pub const fn set_samp_mode(&mut self, val: SampMode)
Sample Mode
Sourcepub const fn set_osc_div(&mut self, val: OscDiv)
pub const fn set_osc_div(&mut self, val: OscDiv)
Oscillator Divide
Sourcepub const fn set_unused4(&mut self, val: bool)
pub const fn set_unused4(&mut self, val: bool)
This bit is unused. Always reads zero.
Sourcepub const fn set_unused5(&mut self, val: bool)
pub const fn set_unused5(&mut self, val: bool)
This bit is unused. Always reads zero.
Sourcepub const fn set_rst_def(&mut self, val: bool)
pub const fn set_rst_def(&mut self, val: bool)
Reset Defaults
Sourcepub const fn set_for_sclk(&mut self, val: bool)
pub const fn set_for_sclk(&mut self, val: bool)
Force System Clock
Sourcepub const fn set_fct_fail(&mut self, val: bool)
pub const fn set_fct_fail(&mut self, val: bool)
Read only: Frequency Count Fail
Sourcepub const fn fct_val(&self) -> bool
pub const fn fct_val(&self) -> bool
Read only: Frequency Count Valid. Indicates that a valid frequency count may be read from FRQCNT.
Sourcepub const fn set_fct_val(&mut self, val: bool)
pub const fn set_fct_val(&mut self, val: bool)
Read only: Frequency Count Valid. Indicates that a valid frequency count may be read from FRQCNT.
Sourcepub const fn set_ent_val(&mut self, val: bool)
pub const fn set_ent_val(&mut self, val: bool)
Read only: Entropy Valid
Sourcepub const fn set_tst_out(&mut self, val: bool)
pub const fn set_tst_out(&mut self, val: bool)
Read only: Test point inside ring oscillator.
Sourcepub const fn set_tstop_ok(&mut self, val: bool)
pub const fn set_tstop_ok(&mut self, val: bool)
TRNG_OK_TO_STOP
Sourcepub const fn set_lrun_cont(&mut self, val: bool)
pub const fn set_lrun_cont(&mut self, val: bool)
Long run count continues between entropy generations